@@ -27,15 +27,12 @@ use autodie;
 
 use File::Spec;
 use List::MoreUtils qw(any);
-use Moo;
 
 use Lintian::Data;
 use Lintian::Relation qw(:constants);
 use Lintian::Spelling qw(check_spelling spelling_tag_emitter);
 use Lintian::Util qw(internal_error strip);
 
-with('Lintian::Check');
-
 use constant NUMPY_REGEX => qr/
     \Qmodule compiled against ABI version \E (?:0x)?%x
     \Q but this version of numpy is \E (?:0x)?%x
@@ -51,6 +48,11 @@ use constant GUILE_PATH_REGEX => qr,^usr/lib/[^/]+/[^/]+/guile/[^/]+/.+\.go$,o;
 #   not strippable for static libs.  Accordingly, it is omitted below.
 use constant DEBUG_SECTIONS => qw(.debug_info .zdebug_info);
 
+use Moo;
+use namespace::clean;
+
+with 'Lintian::Check';
+
 my $ARCH_REGEX = Lintian::Data->new('binaries/arch-regex', qr/\s*\~\~/o,
     sub { return qr/$_[1]/ });
 my $ARCH_64BIT_EQUIVS
