@@ -29,10 +29,9 @@ use warnings;
 use autodie;
 
 use Moo;
+use namespace::clean;
 
-use Lintian::Tags qw(tag);
-
-with('Lintian::Check');
+with 'Lintian::Check';
 
 sub always {
     my ($self) = @_;
@@ -46,8 +45,7 @@ sub always {
     return
       unless defined $menu_item;
 
-    tag 'bad-menu-item', $menu_item
-      unless $menu_item =~ /^\d+$/;
+    $self->tag('bad-menu-item', $menu_item) unless $menu_item =~ /^\d+$/;
 
     return;
 }
