@@ -28,12 +28,12 @@ use strict;
 use warnings;
 use autodie;
 
-use Moo;
-
 use Lintian::Maintainer qw(check_maintainer);
-use Lintian::Tags qw(tag);
 
-with('Lintian::Check');
+use Moo;
+use namespace::clean;
+
+with 'Lintian::Check';
 
 sub source {
     my ($self) = @_;
@@ -47,7 +47,7 @@ sub source {
 
     my $is_list = $maintainer =~ /\@lists(?:\.alioth)?\.debian\.org\b/;
 
-    tag 'no-human-maintainers'
+    $self->tag('no-human-maintainers')
       if $is_list && !defined $info->field('uploaders');
 
     return;
@@ -61,7 +61,7 @@ sub always {
     my $maintainer = $info->unfolded_field('maintainer');
 
     unless (defined $maintainer) {
-        tag 'no-maintainer-field';
+        $self->tag('no-maintainer-field');
         return;
     }
 
