@@ -25,13 +25,16 @@ use warnings;
 use autodie;
 use parent 'Lintian::Collect::Package';
 
+use BerkeleyDB;
 use Carp qw(croak);
+use List::Util qw(any);
+use MLDBM qw(BerkeleyDB::Btree Storable);
 use Path::Tiny;
 
 use Lintian::Deb822Parser qw(parse_dpkg_control);
 use Lintian::Info::Changelog;
 use Lintian::Relation;
-use Lintian::Util qw(internal_error open_gz get_file_checksum strip rstrip);
+use Lintian::Util qw(open_gz get_file_checksum strip rstrip);
 
 use constant EMPTY => q{};
 
@@ -73,8 +76,12 @@ the L<Lintian::Collect> constructor.
 
 sub new {
     my ($class, $pkg) = @_;
+
     my $self = {};
     bless($self, $class);
+
+    $self->{java_info} = {};
+
     return $self;
 }
 
@@ -304,27 +311,22 @@ Needs-Info requirements for using I<scripts>: scripts
 
 sub scripts {
     my ($self) = @_;
-    return $self->{scripts} if exists $self->{scripts};
-    my $scrf = $self->lab_data_path('scripts');
-    my %scripts;
-    if (-f $scrf) {
-        open(my $fd, '<', $scrf);
-        while (my $line = <$fd>) {
-            my (%file, $name);
-            chomp($line);
 
-            $line =~ m/^(env )?(\S*) (.*)$/o
-              or internal_error("bad line in scripts file: $line");
-            ($file{calls_env}, $file{interpreter}, $name) = ($1, $2, $3);
+    unless (exists $self->{scripts}) {
 
-            $name =~ s,^\./,,o;
-            $name =~ s,/+$,,o;
-            $file{name} = $name;
-            $scripts{$name} = \%file;
-        }
-        close($fd);
+        my %scripts;
+
+        my $dbpath = $self->lab_data_path('scripts.db');
+
+        tie my %h, 'MLDBM',-Filename => $dbpath
+          or die "Cannot open file $dbpath: $! $BerkeleyDB::Error\n";
+
+        $scripts{$_} = $h{$_} for keys %h;
+
+        untie %h;
+
+        $self->{scripts} = \%scripts;
     }
-    $self->{scripts} = \%scripts;
 
     return $self->{scripts};
 }
@@ -522,48 +524,28 @@ Needs-Info requirements for using I<java_info>: java-info
 
 sub java_info {
     my ($self) = @_;
-    return $self->{java_info} if exists $self->{java_info};
-    my $javaf = $self->lab_data_path('java-info.gz');
-    my %java_info;
-    if (!-f $javaf) {
-        # no java-info.gz => no jar files to collect data.  Just
-        # return an empty hash ref.
+
+    # do something to prevent second lookup
+    unless (keys %{$self->{java_info}}) {
+
+        my $dbpath = $self->lab_data_path('java-info.db');
+
+        # no jar files
+        return $self->{java_info}
+          unless -f $dbpath;
+
+        my %java_info;
+
+        tie my %h, 'MLDBM',-Filename => $dbpath
+          or die "Cannot open file $dbpath: $! $BerkeleyDB::Error\n";
+
+        $java_info{$_} = $h{$_} for keys %h;
+
+        untie %h;
+
         $self->{java_info} = \%java_info;
-        return $self->{java_info};
     }
-    my $idx = open_gz($javaf);
-    my $file;
-    my $file_list;
-    my $manifest = 0;
-    local $_;
-    while (<$idx>) {
-        chomp;
-        next if m/^\s*$/o;
 
-        if (m#^-- ERROR:\s*(\S.++)$#o) {
-            $java_info{$file}{error} = $1;
-        } elsif (m#^-- MANIFEST: (?:\./)?(?:.+)$#o) {
-            # TODO: check $file == $1 ?
-            $java_info{$file}{manifest} = {};
-            $manifest = $java_info{$file}{manifest};
-            $file_list = 0;
-        } elsif (m#^-- (?:\./)?(.+)$#o) {
-            $file = $1;
-            $java_info{$file}{files} = {};
-            $file_list = $java_info{$file}{files};
-            $manifest = 0;
-        } else {
-            if ($manifest && m#^  (\S+):\s(.*)$#o) {
-                $manifest->{$1} = $2;
-            } elsif ($file_list) {
-                my ($fname, $clmajor) = (m#^([^-].*):\s*([-\d]+)$#);
-                $file_list->{$fname} = $clmajor;
-            }
-
-        }
-    }
-    $self->{java_info} = \%java_info;
-    close($idx);
     return $self->{java_info};
 }
 
@@ -677,11 +659,11 @@ Needs-Info requirements for using I<is_pkg_class>: L<Same as field|Lintian::Coll
         $pkg_class //= 'any-meta';
         if ($pkg_class eq 'debug') {
             return 1 if $self->name =~ m/-dbg(?:sym)?/;
-            return;
+            return 0;
         }
         if ($pkg_class eq 'auto-generated') {
             return 1 if $self->field('auto-built-package');
-            return;
+            return 0;
         }
         return 1 if $desc =~ m/transitional package/;
         $desc = lc($desc);
@@ -692,7 +674,7 @@ Needs-Info requirements for using I<is_pkg_class>: L<Same as field|Lintian::Coll
             return 1 if $section =~ m,(?:^|/)(?:tasks|metapackages)$,;
             return 1 if $self->name =~ m/^task-/;
         }
-        return;
+        return 0;
     }
 }
 
@@ -774,7 +756,7 @@ sub is_conffile {
     return 1
       if exists $self->{conffiles_lookup}{$file};
 
-    return;
+    return 0;
 }
 
 =back
