@@ -26,13 +26,18 @@ use parent 'Lintian::Collect::Package';
 use Carp qw(croak);
 use Scalar::Util qw(blessed);
 use Path::Tiny;
+use Try::Tiny;
 
 use Lintian::Deb822Parser qw(read_dpkg_control);
 use Lintian::Info::Changelog;
+use Lintian::Info::Changelog::Version;
 use Lintian::Relation;
+use Lintian::Tags qw(tag);
 use Lintian::Util
   qw(get_file_checksum open_gz $PKGNAME_REGEX $PKGREPACK_REGEX strip);
 
+use constant EMPTY => q{};
+
 =head1 NAME
 
 Lintian::Collect::Source - Lintian interface to source package data collection
@@ -74,8 +79,12 @@ the Lintian::Collect constructor.
 # which is currently unused.
 sub new {
     my ($class, $pkg) = @_;
+
     my $self = {};
     bless($self, $class);
+
+    $self->{java_info} = {};
+
     return $self;
 }
 
@@ -189,6 +198,41 @@ sub native {
     return $self->{native};
 }
 
+=item version
+
+Returns a fully parsed Lintian::Info::Changelog::Version for the
+source package's version string.
+
+Needs-Info requirements for using I<version>: L<Same as field|Lintian::Collect/field ([FIELD[, DEFAULT]])>
+
+=cut
+
+sub version {
+    my ($self) = @_;
+
+    return $self->{version}
+      if exists $self->{version};
+
+    my $versionstring = $self->field('version', EMPTY);
+
+    my $version = Lintian::Info::Changelog::Version->new;
+    try {
+        $version->set($versionstring, $self->native);
+    } catch {
+        my $indicator= ($self->native ? EMPTY : 'non-') . 'native';
+        tag 'malformed-debian-changelog-version',
+          $versionstring . " (for $indicator)";
+        undef $version;
+    };
+
+    return
+      unless defined $version;
+
+    $self->{version} = $version;
+
+    return $self->{version};
+}
+
 =item files
 
 Returns a reference to a hash containing information about files listed
@@ -284,7 +328,15 @@ Needs-Info requirements for using I<repacked>: L<Same as field|Lintian::Collect/
 sub repacked {
     my ($self) = @_;
     return $self->{repacked} if exists $self->{repacked};
-    $self->{repacked} = $self->field('version', '') =~ $PKGREPACK_REGEX;
+
+    # native packages cannot be repacked
+    if ($self->native) {
+        $self->{repacked} = 0;
+    } else {
+        my $upstream = $self->version->upstream;
+        $self->{repacked} = $upstream =~ $PKGREPACK_REGEX;
+    }
+
     return $self->{repacked};
 }
 
@@ -571,48 +623,28 @@ Needs-Info requirements for using I<java_info>: java-info
 
 sub java_info {
     my ($self) = @_;
-    return $self->{java_info} if exists $self->{java_info};
-    my $javaf = $self->lab_data_path('java-info.gz');
-    my %java_info;
-    if (!-f $javaf) {
-        # no java-info.gz => no jar files to collect data.  Just
-        # return an empty hash ref.
+
+    # do something to prevent second lookup
+    unless (keys %{$self->{java_info}}) {
+
+        my $dbpath = $self->lab_data_path('java-info.db');
+
+        # no jar files
+        return $self->{java_info}
+          unless -f $dbpath;
+
+        my %java_info;
+
+        tie my %h, 'MLDBM',-Filename => $dbpath
+          or die "Cannot open file $dbpath: $! $BerkeleyDB::Error\n";
+
+        $java_info{$_} = $h{$_} for keys %h;
+
+        untie %h;
+
         $self->{java_info} = \%java_info;
-        return $self->{java_info};
     }
-    my $idx = open_gz($javaf);
-    my $file;
-    my $file_list;
-    my $manifest = 0;
-    local $_;
-    while (<$idx>) {
-        chomp;
-        next if m/^\s*$/o;
 
-        if (m#^-- ERROR:\s*(\S.++)$#o) {
-            $java_info{$file}{error} = $1;
-        } elsif (m#^-- MANIFEST: (?:\./)?(?:.+)$#o) {
-            # TODO: check $file == $1 ?
-            $java_info{$file}{manifest} = {};
-            $manifest = $java_info{$file}{manifest};
-            $file_list = 0;
-        } elsif (m#^-- (?:\./)?(.+)$#o) {
-            $file = $1;
-            $java_info{$file}{files} = {};
-            $file_list = $java_info{$file}{files};
-            $manifest = 0;
-        } else {
-            if ($manifest && m#^  (\S+):\s(.*)$#o) {
-                $manifest->{$1} = $2;
-            } elsif ($file_list) {
-                my ($fname, $clmajor) = (m#^([^-].*):\s*([-\d]+)$#);
-                $file_list->{$fname} = $clmajor;
-            }
-
-        }
-    }
-    $self->{java_info} = \%java_info;
-    close($idx);
     return $self->{java_info};
 }
 
