@@ -22,26 +22,33 @@ package Lintian::Processable::Group;
 use strict;
 use warnings;
 
-use Moo;
-
 use Carp;
+use File::Spec;
+use Path::Tiny;
 use Time::HiRes qw(gettimeofday tv_interval);
 
 use Lintian::Collect::Group;
 use Lintian::Output qw(:messages);
-use Lintian::Processable;
+use Lintian::Processable::Binary;
+use Lintian::Processable::Buildinfo;
+use Lintian::Processable::Changes;
+use Lintian::Processable::Source;
+use Lintian::Processable::Udeb;
 use Lintian::Util qw(internal_error get_dsc_info strip);
 
 use constant EMPTY => q{};
 
-has lab => (is => 'rw');
-has name => (is => 'rw', default => EMPTY);
+use Moo;
+use namespace::clean;
 
-has source => (is => 'rw');
-has changes => (is => 'rw');
-has buildinfo => (is => 'rw');
-has binary => (is => 'rw', default => sub{ {} });
-has udeb => (is => 'rw', default => sub{ {} });
+# A private table of supported types.
+my %SUPPORTED_TYPES = (
+    'binary'  => 1,
+    'buildinfo' => 1,
+    'changes' => 1,
+    'source'  => 1,
+    'udeb'    => 1,
+);
 
 =head1 NAME
 
@@ -69,12 +76,85 @@ and one changes or buildinfo package per set, but multiple binary packages
 
 =over 4
 
+=item $group->lab
+
+Returns or sets the lab used by this pool.
+
+=item $group->name
+
+Returns a unique identifier for the group based on source and version.
+
+=item $group->binary
+
+Returns a hash reference to the binary processables in this group.
+
+=item $group->buildinfo
+
+Returns the buildinfo processable in this group.
+
+=item $group->changes
+
+Returns the changes processable in this group.
+
+=item $group->source
+
+Returns the source processable in this group.
+
+=item $group->udeb
+
+Returns a hash reference to the udeb processables in this group.
+
+=cut
+
+has lab => (is => 'rw');
+has name => (is => 'rw', default => EMPTY);
+
+has binary => (is => 'rw', default => sub{ {} });
+has buildinfo => (is => 'rw');
+has changes => (is => 'rw');
+has source => (is => 'rw');
+has udeb => (is => 'rw', default => sub{ {} });
+
 =item Lintian::Processable::Group->init_from_file (FILE)
 
 Add all processables from .changes or .buildinfo file FILE.
 
 =cut
 
+sub _get_processable {
+    my ($self, $file) = @_;
+
+    my $absolute = path($file)->realpath->stringify;
+    croak "Cannot resolve $file: $!"
+      unless $absolute;
+
+    my $processable;
+
+    if ($file =~ m/\.dsc$/o) {
+        $processable = Lintian::Processable::Source->new;
+
+    } elsif ($file =~ m/\.buildinfo$/o) {
+        $processable = Lintian::Processable::Buildinfo->new;
+
+    } elsif ($file =~ m/\.deb$/o) {
+        $processable = Lintian::Processable::Binary->new;
+
+    } elsif ($file =~ m/\.udeb$/o) {
+        $processable = Lintian::Processable::Udeb->new;
+
+    } elsif ($file =~ m/\.changes$/o) {
+        $processable = Lintian::Processable::Changes->new;
+
+    } else {
+        croak "$file is not a known type of package";
+    }
+
+    $processable->lab($self->lab);
+    $processable->init($absolute);
+
+    return $processable;
+}
+
 #  populates $self from a buildinfo or changes file.
 sub init_from_file {
     my ($self, $path) = @_;
@@ -82,7 +162,7 @@ sub init_from_file {
     return
       unless defined $path;
 
-    my $processable = Lintian::Processable::Package->new($path);
+    my $processable = $self->_get_processable($path);
     $self->add_processable($processable);
 
     my ($type) = $path =~ m/\.(buildinfo|changes)$/;
@@ -138,33 +218,13 @@ sub init_from_file {
             next;
         }
 
-        my $payload = Lintian::Processable::Package->new("$dir/$file");
+        my $payload = $self->_get_processable("$dir/$file");
         $self->add_processable($payload);
     }
 
     return 1;
 }
 
-=item prep_unpack_error
-
-Error handler.
-
-=cut
-
-sub prep_unpack_error {
-    my ($self, $action, $exit_code_ref, $lpkg) = @_;
-    my $err = $!;
-    my $pkg_type = $lpkg->pkg_type;
-    my $pkg_name = $lpkg->pkg_name;
-    warning(
-        "could not create the package entry in the lab: $err",
-        "skipping $action of $pkg_type package $pkg_name"
-    );
-    $$exit_code_ref = 2;
-    $self->remove_processable($lpkg);
-    return;
-}
-
 =item unpack
 
 Unpack this group.
@@ -173,29 +233,47 @@ Unpack this group.
 
 sub unpack {
     my ($self, $unpacker, $action, $exit_code_ref)= @_;
+
     my $all_ok = 1;
-    my $errhandler = sub {
-        $all_ok = 0;
-        $self->prep_unpack_error($action, $exit_code_ref, @_);
-    };
 
     # Kill pending jobs, if any
     $unpacker->kill_jobs;
     $unpacker->reset_worklist;
 
     # Stop here if there is nothing list for us to do
-    return
-      unless $unpacker->prepare_tasks($errhandler, $self->get_processables);
+    my @processables = $self->get_processables;
+    for my $processable (@processables) {
+
+        $processable->create;
+
+        # for sources pull in all related files so unpacked does not fail
+        if ($processable->pkg_type eq 'source') {
+            my (undef, $dir, undef)
+              = File::Spec->splitpath($processable->pkg_path);
+            for my $fs (split(m/\n/o, $processable->info->field('files'))) {
+                strip($fs);
+                next if $fs eq '';
+                my @t = split(/\s+/o,$fs);
+                next if ($t[2] =~ m,/,o);
+                symlink("$dir/$t[2]", $processable->base_dir . "/$t[2]")
+                  or croak("cannot symlink file $t[2]: $!");
+            }
+        }
+    }
+
+    return 0
+      unless $unpacker->prepare_tasks(@processables);
 
     v_msg('Unpacking packages in group ' . $self->name);
 
-    my (%timers, %hooks);
-    $hooks{'coll-hook'}= sub {
+    my %timers;
+    my $hook = sub {
         $self->coll_hook($action, $exit_code_ref, \%timers, @_)
           or $all_ok = 0;
     };
 
-    $unpacker->process_tasks(\%hooks);
+    $unpacker->process_tasks($hook);
+
     return $all_ok;
 }
 
@@ -206,50 +284,46 @@ Collection hook.
 =cut
 
 sub coll_hook {
-    my (
-        $self, $action, $exit_code_ref,$timers, $lpkg,
-        $event, $cs, $task_id, $exitval
-    )= @_;
-    my $coll = $cs->name;
-    my $procid = $lpkg->identifier;
-    my $ok = 1;
+    my ($self, $action, $exit_code_ref,$timers, $task, $event, $exitval)= @_;
+
+    my $coll = $task->script->name;
+    my $procid = $task->labentry->identifier;
+    my $pkg_name = $task->labentry->pkg_name;
+    my $pkg_type = $task->labentry->pkg_type;
 
     if ($event eq 'start') {
-        $timers->{$task_id} = [gettimeofday];
+        $timers->{$task->id} = [gettimeofday];
         debug_msg(1, "Collecting info: $coll for $procid ...");
-    } elsif ($event eq 'start-failed') {
+
+        return 1;
+
+    } elsif ($event eq 'start-failed' || ($event eq 'finish' && $exitval)) {
+
         # failed
-        my $pkg_name = $lpkg->pkg_name;
-        my $pkg_type = $lpkg->pkg_type;
-        warning(
-            "collect info $coll about package $pkg_name failed",
-            "skipping $action of $pkg_type package $pkg_name",
-            "error: $exitval"
-        );
+        my $string
+          = "collection $coll failed for $pkg_type package $pkg_name, skipping $action";
+        $string .= " error: $exitval"
+          if $exitval;
+        warning($string);
+
+        $self->remove_processable($task->labentry);
         $$exit_code_ref = 2;
-        $ok = 0;
-        $self->remove_processable($lpkg);
+
+        return 0;
+
     } elsif ($event eq 'finish') {
-        if ($exitval) {
-            # Failed
-            my $pkg_name  = $lpkg->pkg_name;
-            my $pkg_type = $lpkg->pkg_type;
-            warning(
-                "collect info $coll about package $pkg_name failed ($exitval)"
-            );
-            warning("skipping $action of $pkg_type package $pkg_name");
-            $$exit_code_ref = 2;
-            $ok = 0;
-            $self->remove_processable($lpkg);
-        } else {
-            # success
-            my $raw_res = tv_interval($timers->{$task_id});
-            my $tres = sprintf('%.3fs', $raw_res);
-            debug_msg(1, "Collection script $coll for $procid done ($tres)");
-            perf_log("$procid,coll/$coll,${raw_res}");
-        }
+
+        # success
+        my $raw_res = tv_interval($timers->{$task->id});
+        my $tres = sprintf('%.3fs', $raw_res);
+        debug_msg(1, "Collection script $coll for $procid done ($tres)");
+        perf_log("$procid,coll/$coll,${raw_res}");
+
+        return 0;
     }
-    return $ok;
+
+    # unknown event
+    return 1;
 }
 
 =item post_pkg_process_overrides
@@ -447,22 +521,31 @@ sub add_processable{
     croak 'Please set lab first.'
       unless $self->lab;
 
-    my $mapped = $self->lab->get_package($processable);
+    croak "Not a supported type ($pkg_type)"
+      unless exists $SUPPORTED_TYPES{$pkg_type};
+
+    my $dir = $self->_pool_path(
+        $processable->pkg_src,$processable->pkg_type,
+        $processable->pkg_name,$processable->pkg_version,
+        $processable->pkg_arch
+    );
+
+    $processable->base_dir($dir);
 
     if ($pkg_type eq 'changes') {
         internal_error("Cannot add another $pkg_type file")
           if $self->changes;
-        $self->changes($mapped);
+        $self->changes($processable);
 
     } elsif ($pkg_type eq 'buildinfo') {
         # Ignore multiple .buildinfo files; use the first one
-        $self->buildinfo($mapped)
+        $self->buildinfo($processable)
           unless $self->buildinfo;
 
     } elsif ($pkg_type eq 'source'){
         internal_error('Cannot add another source package')
           if $self->source;
-        $self->source($mapped);
+        $self->source($processable);
 
     } else {
         my $phash;
@@ -475,12 +558,42 @@ sub add_processable{
         return 0
           if exists $phash->{$id};
 
-        $phash->{$id} = $mapped;
+        $phash->{$id} = $processable;
     }
     $processable->group($self);
     return 1;
 }
 
+# Given the package meta data (src_name, type, name, version, arch) return the
+# path to it in the Lab.  The path returned will be absolute.
+sub _pool_path {
+    my ($self, $pkg_src, $pkg_type, $pkg_name, $pkg_version, $pkg_arch) = @_;
+
+    my $dir = $self->lab->basedir;
+    my $p;
+
+    # If it is at least 4 characters and starts with "lib", use "libX"
+    # as prefix
+    if ($pkg_src =~ m/^lib./o) {
+        $p = substr $pkg_src, 0, 4;
+    } else {
+        $p = substr $pkg_src, 0, 1;
+    }
+
+    $p  = "$p/$pkg_src/${pkg_name}_${pkg_version}";
+    $p .= "_${pkg_arch}" unless $pkg_type eq 'source';
+    $p .= "_${pkg_type}";
+
+    # Turn spaces into dashes - spaces do appear in architectures
+    # (i.e. for changes files).
+    $p =~ s/\s/-/go;
+
+    # Also replace ":" with "_" as : is usually used for path separator
+    $p =~ s/:/_/go;
+
+    return "$dir/pool/$p";
+}
+
 =item $group->get_processables([$type])
 
 Returns an array of all processables in $group.  The processables are
